Class: Decidim::Assemblies::AdminLog::AssemblyUserRolePresenter

Inherits:
Log::BasePresenter
  • Object
show all
Defined in:
app/presenters/decidim/assemblies/admin_log/assembly_user_role_presenter.rb

Overview

This class holds the logic to present a Decidim::AssemblyUserRole for the AdminLog log.

Usage should be automatic and you should not need to call this class directly, but here is an example:

action_log = Decidim::ActionLog.last
view_helpers # => this comes from the views
AssemblyUserRolePresenter.new(action_log, view_helpers).present